==> piwigo-2.5.1.zip: piwigo/language/he_IL/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2013 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = "שדרג";
$lang['Upgrade from version %s to %s'] = "שדרג מגירסה %s ל %s";
$lang['Statistics'] = "סטטיסטיקה";
$lang['total upgrade time'] = "זמן שידרוג כולל";
$lang['total SQL time'] = "זמןSQLכולל";
$lang['SQL queries'] = "SQLשאילתות";
$lang['Upgrade informations'] = "מידע לשידרוג";
$lang['User permissions and group permissions have been erased'] = 'הרשאות משתמשים וקבוצות נמחקו';
$lang['Only administrator can run upgrade: please sign in below.'] = 'רק מנהל יכול להריץ שדרוג : בבקשה התחבר למטה';
$lang['You do not have access rights to run upgrade'] = 'אין לך גישה להפעיל שדרוג';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'דף זה מציע לשדרג את מסד הנתונים מגרסת Piwigo הישנה לגרסה החדשה. עוזר השדרוג חושב שאתה מפעיל כרגע <strong>שחרור %s</strong>.';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'רק תמונות ממוזערות, ודואר אלקטרוני של מנהל האתר נשמרו מהגירסה הקודמת';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'בצע בדיקת תחזוקה ב[ ניהול> כלים> תחזוקה] אם נתקלת בעיה כלשהי.';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'כאמצעי זהירות הערכות הבאות בוטלו, בדוק עדכונם לפני הפעלתם המחודשת:';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'בתוך <i>%s</i>, לפני <b>?></b>, הכנס:';
$lang['All sub-albums of private albums become private'] = 'כל אלבומי משנה של אלבומים פרטיים יהפכו לפרטים';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'התוספים הבאים בוטלו כאמצעי זהירות, בדוק אפשרות לעדכונם טרם הפעלתם המחודשת:';
?>

==> piwigo-2.9.5.zip: piwigo/language/he_IL/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2016 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Upgrade'] = "שדרג";
$lang['Upgrade from version %s to %s'] = "שדרג מגירסה %s ל %s";
$lang['Statistics'] = 'סטטיסטיקות';
$lang['total upgrade time'] = "זמן שידרוג כולל";
$lang['total SQL time'] = 'זמן SQL כולל';
$lang['SQL queries'] = 'שאילתות SQL';
$lang['Upgrade informations'] = "מידע לשידרוג";
$lang['User permissions and group permissions have been erased'] = 'הרשאות משתמשים וקבוצות נמחקו';
$lang['Only administrator can run upgrade: please sign in below.'] = 'רק מנהל יכול להריץ שדרוג : בבקשה התחבר למטה';
$lang['You do not have access rights to run upgrade'] = 'אין לך הרשאות גישה לבצע שדרוג';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'דף זה מציע לשדרג את מסד הנתונים מגרסת Piwigo הישנה לגרסה החדשה. עוזר השדרוג חושב שאתה מפעיל כרגע <strong>שחרור %s</strong>.';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = 'רק תמונות ממוזערות, ודואר אלקטרוני של מנהל האתר נשמרו מהגירסה הקודמת';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = 'בצע בדיקת תחזוקה ב[ ניהול> כלים> תחזוקה] אם נתקלת בעיה כלשהי.';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = 'כאמצעי זהירות הערכות הבאות בוטלו, בדוק עדכונם לפני הפעלתם המחודשת:';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = 'בתוך <i>%s</i>, לפני <b>?></b>, הכנס:';
$lang['All sub-albums of private albums become private'] = 'כל אלבומי משנה של אלבומים פרטיים יהפכו לפרטים';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = 'התוספים הבאים בוטלו כאמצעי זהירות, בדוק אפשרות לעדכונם טרם הפעלתם המחודשת:';
$lang['Discover what\'s new in Piwigo %s'] = 'גלו מה התחדש בפיוויגו %s';
